@@ -27,6 +27,8 @@ class ColemenDatabase:
         self.con = None
         self.cur = None
 
+        self.data['tables_cols_cache'] = {}
+
     def connect(self, **kwargs):
         '''
             Sets up the database connection with the initial settings.
@@ -279,7 +281,7 @@ class ColemenDatabase:
             print(traceback.format_exc())
 
         except sqlite3.OperationalError as error:
-            print(f"Fatal Error: {error}\n\t{sql}")
+            print(f"Fatal Error: {error}")
             print(traceback.format_exc())
 
         except AttributeError:
@@ -453,7 +455,9 @@ class ColemenDatabase:
             `version`: 1.0
             `method_name`: filter_dict_by_columns
         '''
-        column_array = self.table.get_column_array(table_name)
+        if table_name not in self.data['tables_cols_cache']:
+            self.data['tables_cols_cache'][table_name] = self.table.get_column_array(table_name)
+        column_array = self.data['tables_cols_cache'][table_name]
         finalDict = {}
         for c in column_array:
             if c in data_dict:
